#ifndef __SUPP_H__
#define __SUPP_H__

/* Data packet size */
#define DATA_SIZE 1024

/* Flags */
#define FLAG_SYN 1
#define FLAG_FIN 2
#define FLAG_ACK 4
#define FLAG_RST 8

/* Data packet */
typedef struct 
{
    unsigned char from[4];
    unsigned char to[4];
    unsigned int from_port;
    unsigned int to_port;
    unsigned long id1, id2;
    unsigned int length;
    unsigned long flags;
    unsigned char data[DATA_SIZE + 1];
} PACKET;

/* Packet size */
#define PACKET_SIZE sizeof(PACKET)

/* Network timeout */
#define NET_TIMEOUT 1000

/* Network retries */
#define NET_RETRIES 10

/* Sleep time at connection end */
#define FINAL_SLEEP 2

/* Retries counter */
extern int retries;

/* Timer counter */
extern int timer;

/* Send and recive packets */
extern PACKET snd, rcv;

/* Data to be sent */
extern char data[DATA_SIZE];

/* Length of data to send */
extern int data_len;

/* Error number */
extern bool error;

/* Is connection timed out */
extern bool timedout;

/* Is packet outtimed */
extern bool old_pack;

/* Port number */
extern unsigned int port;

/* Server address */
extern char *to_adr;

/* Initialize low level connection */
bool init(void);

/* Close low level connection */
bool end(void);

/* Low level listen for connection */
bool listen(void);

/* Low level send packet */
bool send(void);

/* Low level receive packet */
bool recive(void);

/* Low level check for new packet */
bool check_data(void);

/* Low level wait for new packet */
bool wait_data(void);

/* Low level send RST packet */
void send_rst(void);

/* Low level send SYN packet */
void send_syn(void);

/* Low level send SYN ACK packet */
void send_syn_ack(void);

/* Low level send FIN packet */
void send_fin(void);

/* Low level send ACK packet */
void send_ack(void);

/* Low level send data packet */
void send_data(void);

#endif
